@@ -3,12 +3,13 @@
 /*
 htop - DateTimeMeter.h
 (C) 2004-2011 Hisham H. Muhammad
-Released under the GNU GPL, see the COPYING file
+Released under the GNU GPLv2+, see the COPYING file
 in the source distribution for its full text.
 */
 
 #include "Meter.h"
 
+
 extern const MeterClass DateTimeMeter_class;
 
 #endif
